#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 validation-selective
version:              0.2.0.0
visibility:           public
id:                   validation-selective-0.2.0.0-GPLYpC0tYghF1UHasTtQTt
key:                  validation-selective-0.2.0.0-GPLYpC0tYghF1UHasTtQTt
license:              MPL-2.0
copyright:            2020-2023 Kowainik
maintainer:           Kowainik <xrom.xkov@gmail.com>
author:               Dmitrii Kovanikov, Veronika Romashkina
homepage:             https://github.com/kowainik/validation-selective
synopsis:
    Lighweight pure data validation based on Applicative and Selective functors

description:
    Lighweight pure data validation based on Applicative and Selective
    functors. The library builds validation interface around the
    following data type:

    @
    __data__ Validation e a
    \    = Failure e
    \    | Success a
    @

category:             Validation, Selective, Data
abi:                  b6d109338b05b64d084b9ff6decb0e22
exposed:              True
exposed-modules:      Validation Validation.Combinators
import-dirs:          /usr/lib/ghc-9.6.6/site-local/validation-selective-0.2.0.0
library-dirs:         /usr/lib/ghc-9.6.6/site-local/validation-selective-0.2.0.0
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/validation-selective-0.2.0.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-validation-selective
hs-libraries:         HSvalidation-selective-0.2.0.0-GPLYpC0tYghF1UHasTtQTt
depends:
    base-4.18.2.1 deepseq-1.4.8.1
    selective-0.7.0.1-AGfRx8rPJtyXI3m0qmEUx

haddock-interfaces:
    /usr/share/doc/haskell-validation-selective/html/validation-selective.haddock

haddock-html:         /usr/share/doc/haskell-validation-selective/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

